==> haskell-listlike-4.6-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.6
id: ListLike-4.6-CqbsYp4FexjGX2KY2TVvvV
key: ListLike-4.6-CqbsYp4FexjGX2KY2TVvvV
license: BSD-3-Clause
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: John Lato <jwlato@gmail.com>
author: John Goerzen
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generic support for list-like structures
description:
    Generic support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: Generics
abi: 0e132cdafae4cf25f1ab465358b5ade0
exposed: True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.CharString
    Data.ListLike.Chars Data.ListLike.DList Data.ListLike.FMList
    Data.ListLike.FoldableLL Data.ListLike.IO Data.ListLike.Instances
    Data.ListLike.String Data.ListLike.Text Data.ListLike.Text.Builder
    Data.ListLike.Text.Text Data.ListLike.Text.TextLazy
    Data.ListLike.UTF8 Data.ListLike.Utils Data.ListLike.Vector
    Data.ListLike.Vector.Generic Data.ListLike.Vector.Storable
    Data.ListLike.Vector.Unboxed Data.ListLike.Vector.Vector
import-dirs: /usr/lib/ghc-8.4.3/site-local/ListLike-4.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/ListLike-4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ListLike-4.6
hs-libraries: HSListLike-4.6-CqbsYp4FexjGX2KY2TVvvV
depends:
    base-4.11.1.0 containers-0.5.11.0 bytestring-0.10.8.2 array-0.5.2.0
    text-1.2.3.0 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
    fmlist-0.9.2-JnZzqaMj889IzujtoT1sSF
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             fmlist-0.9.2-JnZzqaMj889IzujtoT1sSF=85c2f2c2db2f262afdcf7a5fa23f4d9b
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-listlike-4.6-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.6
id: ListLike-4.6-3Z547COdop48WLCEwLJgjm
key: ListLike-4.6-3Z547COdop48WLCEwLJgjm
license: BSD-3-Clause
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: John Lato <jwlato@gmail.com>
author: John Goerzen
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generic support for list-like structures
description:
    Generic support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: Generics
abi: 1f970578cc30e74eda945bf514ab86d8
exposed: True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.CharString
    Data.ListLike.Chars Data.ListLike.DList Data.ListLike.FMList
    Data.ListLike.FoldableLL Data.ListLike.IO Data.ListLike.Instances
    Data.ListLike.String Data.ListLike.Text Data.ListLike.Text.Builder
    Data.ListLike.Text.Text Data.ListLike.Text.TextLazy
    Data.ListLike.UTF8 Data.ListLike.Utils Data.ListLike.Vector
    Data.ListLike.Vector.Generic Data.ListLike.Vector.Storable
    Data.ListLike.Vector.Unboxed Data.ListLike.Vector.Vector
import-dirs: /usr/lib/ghc-8.4.3/site-local/ListLike-4.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/ListLike-4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ListLike-4.6
hs-libraries: HSListLike-4.6-3Z547COdop48WLCEwLJgjm
depends:
    base-4.11.1.0 containers-0.5.11.0 bytestring-0.10.8.2 array-0.5.2.0
    text-1.2.3.0 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6
    fmlist-0.9.2-JnZzqaMj889IzujtoT1sSF
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6=f0c6d817a8f4177a2d0e3837521bb503
             fmlist-0.9.2-JnZzqaMj889IzujtoT1sSF=85c2f2c2db2f262afdcf7a5fa23f4d9b
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
